// import { useNavigate } from "react-router-dom";
import { useEffect, useState } from "react";
import Button from "../../Base/button";
import "./seat-layout.css";
import Seat from "../seat";
import Confirmation from "../confirmation";

function SeatLayout({
  userId = 1,
  seats,
  reservedSeats,
  selectedSeats,
  onClick,
  ...props
}) {
  // const navigate = useNavigate();
  const [selectedseat, setSelectedSeat] = useState([...selectedSeats]);
  const [confirmation, setConfirmation] = useState(false);
  const handleSeats = (seat) => {
    if (!selectedseat?.includes(seat)) {
      setSelectedSeat([...selectedseat, seat]);
    } else {
      setSelectedSeat(selectedseat?.filter((e) => e != seat));
    }
  };
  useEffect(() => {
    setSelectedSeat([...selectedSeats]);
  }, [selectedSeats]);
  const handleConfirm = (e) => {
    e.preventDefault();
    //check if already have data then update otherwise create,
    //write code
    onClick({ userId: parseInt(userId), seats: selectedseat });
    setTimeout(() => {
      setConfirmation(true);
    }, 500);
  };

  return (
    <>
      {!confirmation ? (
        <div className="container">
          <h1>Choose Seats</h1>
          <div className="curve">
            <div className="curve-shadow"></div>
          </div>
          <div className="seat-container">
            {seats?.map((seat) => (
              <div className="seat">
                {seat?.map((e, i) => (
                  <div className={`${e === 0 ? "remove-seats" : ""}`}>
                    <Seat
                      key={e}
                      onChange={() => handleSeats(e)}
                      status={
                        selectedseat?.includes(e)
                          ? "selected"
                          : reservedSeats?.includes(e)
                          ? "reserved"
                          : "available"
                      }
                    />
                  </div>
                ))}
              </div>
            ))}
          </div>
          <Button onClick={handleConfirm} {...props}>
            Confirm
          </Button>
          <div className="seat-status">
            <div className="selected">
              <div></div>
              <p>Selected</p>
            </div>
            <div className="reserved">
              <div></div>
              <p>Reserved</p>
            </div>
            <div className="available">
              <div></div>
              <p>Available</p>
            </div>
          </div>
        </div>
      ) : (
        <Confirmation ticketCount={selectedseat.length} seats={selectedseat} />
      )}
    </>
  );
}
SeatLayout.defaultProps = {
  seats: [],
  reservedSeats: [],
  selectedSeats: [],
  onClick: () => {},
};
export default SeatLayout;
